@@ -76,47 +76,122 @@ use std::{
     rc::Rc,
     sync::{Arc, Mutex, RwLock},
 };
+
 /// Utility functions and macros.
+#[cfg(feature = "internal")]
 #[macro_use]
 pub mod util;
+#[cfg(feature = "internal")]
 /// Compilation of builtin functions.
 pub mod builtin;
+#[cfg(feature = "internal")]
 /// Storage of variable length values : ByteStorage.
 pub mod bytes;
-/// Cache to retain page values at different times.
-pub mod cache;
+#[cfg(feature = "internal")]
+/// Stash to retain page values at different times.
+pub mod stash;
+#[cfg(feature = "internal")]
 /// Structs that implement CExp trait.
 pub mod cexp;
+#[cfg(feature = "internal")]
 /// CompactFile : storage of logical pages in smaller regions of backing storage.
 pub mod compact;
+#[cfg(feature = "internal")]
 /// Functions to compile parsed expressions, checking types.
 pub mod compile;
+#[cfg(feature = "internal")]
 /// Instruction execution.
 pub mod exec;
+#[cfg(feature = "internal")]
 /// Expression types, result of parsing.
 pub mod expr;
-/// Under development.
-pub mod genquery;
-/// Initial SQL
-pub mod init;
+#[cfg(feature = "internal")]
 /// Page for SortedFile.
 pub mod page;
+#[cfg(feature = "internal")]
 /// Parser.
 pub mod parse;
 /// Paged data storage.
 pub mod pstore;
+#[cfg(feature = "internal")]
 /// Instruction and other run time types.
 pub mod run;
+#[cfg(feature = "internal")]
 /// Sorted Record storage.
 pub mod sortedfile;
-/// Backing storage for CompactFile.
-pub mod stg;
+#[cfg(feature = "internal")]
 /// System table functions.
 pub mod sys;
+#[cfg(feature = "internal")]
 /// Table, ColInfo, Row and other Table types.
 pub mod table;
+#[cfg(feature = "internal")]
 /// Run-time Value.
 pub mod value;
+
+#[cfg(feature = "minimal")]
+#[macro_use]
+mod util;
+#[cfg(feature = "minimal")]
+/// Compilation of builtin functions.
+mod builtin;
+#[cfg(feature = "minimal")]
+/// Storage of variable length values : ByteStorage.
+mod bytes;
+#[cfg(feature = "minimal")]
+/// Stash to retain page values at different times.
+mod stash;
+#[cfg(feature = "minimal")]
+/// Structs that implement CExp trait.
+mod cexp;
+#[cfg(feature = "minimal")]
+/// CompactFile : storage of logical pages in smaller regions of backing storage.
+mod compact;
+#[cfg(feature = "minimal")]
+/// Functions to compile parsed expressions, checking types.
+mod compile;
+#[cfg(feature = "minimal")]
+/// Instruction execution.
+mod exec;
+#[cfg(feature = "minimal")]
+/// Expression types, result of parsing.
+mod expr;
+
+#[cfg(feature = "minimal")]
+/// Page for SortedFile.
+mod page;
+#[cfg(feature = "minimal")]
+/// Parser.
+mod parse;
+
+#[cfg(feature = "minimal")]
+/// Instruction and other run time types.
+mod run;
+#[cfg(feature = "minimal")]
+/// Sorted Record storage.
+mod sortedfile;
+
+#[cfg(feature = "minimal")]
+/// System table functions.
+mod sys;
+#[cfg(feature = "minimal")]
+/// Table, ColInfo, Row and other Table types.
+mod table;
+#[cfg(feature = "minimal")]
+/// Run-time Value.
+mod value;
+
+// Modules that are always public.
+
+/// GenQuery.
+pub mod genquery;
+
+/// Initial SQL
+pub mod init;
+
+/// Backing storage for CompactFile.
+pub mod stg;
+
 /// WebQuery struct for making a http web server.
 pub mod web;
 
@@ -245,12 +320,23 @@ GO
         builtin::register_builtins(&db);
         db
     }
+
+    #[cfg(feature = "internal")]
     /// Register a builtin function.
     pub fn register(self: &DB, name: &str, typ: DataKind, cf: CompileFunc) {
         self.builtins
             .borrow_mut()
             .insert(name.to_string(), (typ, cf));
     }
+
+    #[cfg(feature = "minimal")]
+    /// Register a builtin function.
+    fn register(self: &DB, name: &str, typ: DataKind, cf: CompileFunc) {
+        self.builtins
+            .borrow_mut()
+            .insert(name.to_string(), (typ, cf));
+    }
+
     /// Run a batch of SQL.
     pub fn run(self: &DB, source: &str, qy: &mut dyn Query) {
         if let Some(e) = self.go(source, qy) {
