@@ -1,10 +1,10 @@
-use crate::cache::Cache;
+use crate::stash::Stash;
 use crate::{Arc, CompactFile, Data, HashMap, RwLock, SaveOp, Storage};
 
 /// Inner for SharedPagedData.
 pub struct SPSInner {
     pub file: CompactFile,
-    pub stash: Cache<Data>,
+    pub stash: Stash<Data>,
     pub cache: HashMap<u64, Data>,
 }
 
@@ -24,7 +24,7 @@ impl SharedPagedData {
         Self {
             x: RwLock::new(SPSInner {
                 file,
-                stash: Cache::new(),
+                stash: Stash::new(),
                 cache: HashMap::new(),
             }),
             sp_size,
